@@ -2,7 +2,7 @@
 #
 # COPYRIGHT:
 #
-# This software is Copyright (c) 1996-2023 Best Practical Solutions, LLC
+# This software is Copyright (c) 1996-2025 Best Practical Solutions, LLC
 #                                          <sales@bestpractical.com>
 #
 # (Except where explicitly superseded by other copyright notices)
@@ -149,7 +149,7 @@ sometimes when you have big mail loops you may hit it.
 Defaults to 1000.  To change this (for example, to 10000) add the
 following to your F<RT_SiteConfig.pm>:
 
-    Set( $DependenciesLimit, 10_000 );>
+    Set( $DependenciesLimit, 10_000 );
 
 
 =head2 $ShredderStoragePath
@@ -160,7 +160,7 @@ F</opt/rt5/var/data/RT-Shredder> (assuming an /opt/rt5 installation).
 To change this (for example, to /some/backup/path) add the following to
 your F<RT_SiteConfig.pm>:
 
-    Set( $ShredderStoragePath, "/some/backup/path" );>
+    Set( $ShredderStoragePath, "/some/backup/path" );
 
 Be sure to specify an absolute path.
 
@@ -235,6 +235,7 @@ BEGIN {
 
 our @SUPPORTED_OBJECTS = qw(
     ACE
+    Asset
     Attachment
     CachedGroupMember
     CustomField
@@ -312,9 +313,9 @@ sub _Init
 
 =head4 CastObjectsToRecords( Objects => undef )
 
-Cast objects to the C<RT::Record> objects or its ancesstors.
+Cast objects to the C<RT::Record> objects or its ancestors.
 Objects can be passed as SCALAR (format C<< <class>-<id> >>),
-ARRAY, C<RT::Record> ancesstors or C<RT::SearchBuilder> ancesstor.
+ARRAY, C<RT::Record> ancestors or C<RT::SearchBuilder> ancestor.
 
 Most methods that takes C<Objects> argument use this method to
 cast argument value to list of records.
@@ -351,6 +352,8 @@ sub CastObjectsToRecords
         while( my $tmp = $targets->Next ) { push @res, $tmp };
     } elsif ( UNIVERSAL::isa( $targets, 'RT::Record' ) ) {
         push @res, $targets;
+    } elsif ( UNIVERSAL::isa( $targets, 'RT::Shredder::RawRecord' ) ) {
+        push @res, $targets;
     } elsif ( UNIVERSAL::isa( $targets, 'ARRAY' ) ) {
         foreach( @$targets ) {
             push @res, $self->CastObjectsToRecords( Objects => $_ );
@@ -427,8 +430,8 @@ sub PutObjects
 
 Puts record object into cache and returns its cache entry.
 
-B<NOTE> that this method support B<only C<RT::Record> object or its ancesstor
-objects>, if you want put mutliple objects or objects represented by different
+B<NOTE> that this method support B<only C<RT::Record> object or its ancestor
+objects>, if you want put multiple objects or objects represented by different
 classes then use C<PutObjects> method instead.
 
 =cut
@@ -439,7 +442,7 @@ sub PutObject
     my %args = ( Object => undef, @_ );
 
     my $obj = $args{'Object'};
-    unless( UNIVERSAL::isa( $obj, 'RT::Record' ) ) {
+    if( !UNIVERSAL::isa( $obj, 'RT::Record' ) && !UNIVERSAL::isa( $obj, 'RT::Shredder::RawRecord' ) ) {
         RT::Shredder::Exception->throw( "Unsupported type '". (ref $obj || $obj || '(undef)')."'" );
     }
 
@@ -653,7 +656,7 @@ path by next rules:
 
 * if C<FileName> has C<XXXX> (exactly four uppercase C<X> letters) then it would be changed with digits from 0000 to 9999 range, with first one free value;
 
-* if C<FileName> has C<%T> then it would be replaced with the current date and time in the C<YYYY-MM-DDTHH:MM:SS> format. Note that using C<%t> may still generate not unique names, using C<XXXX> recomended.
+* if C<FileName> has C<%T> then it would be replaced with the current date and time in the C<YYYY-MM-DDTHH:MM:SS> format. Note that using C<%t> may still generate not unique names, using C<XXXX> recommended.
 
 * if C<FromStorage> argument is true (default behaviour) then result path would always be relative to C<StoragePath>;
 
@@ -822,6 +825,8 @@ sub RollbackDumpTo {
 }
 }
 
+RT::Base->_ImportOverlays();
+
 1;
 __END__
 
