@@ -2,7 +2,7 @@
 #
 # COPYRIGHT:
 #
-# This software is Copyright (c) 1996-2023 Best Practical Solutions, LLC
+# This software is Copyright (c) 1996-2025 Best Practical Solutions, LLC
 #                                          <sales@bestpractical.com>
 #
 # (Except where explicitly superseded by other copyright notices)
@@ -69,6 +69,7 @@ my $Test_NoWarnings_Catcher = $SIG{__WARN__};
 my $check_warnings_in_end   = 1;
 
 use Socket;
+use IO::Socket::INET;
 use File::Temp qw(tempfile);
 use File::Path qw(mkpath);
 use File::Spec;
@@ -96,7 +97,7 @@ RT::Test - RT Testing
 
 =head2 COVERAGE
 
-To run the rt test suite with coverage support, install L<Devel::Cover> and run:
+To run the RT test suite with coverage support, install L<Devel::Cover> and run:
 
     make test RT_DBA_USER=.. RT_DBA_PASSWORD=.. HARNESS_PERL_SWITCHES=-MDevel::Cover
     cover -ignore_re '^var/mason_data/' -ignore_re '^t/'
@@ -256,14 +257,17 @@ sub find_idle_port {
         # server binds.  However, since we mostly care about race
         # conditions with ourselves under high concurrency, this is
         # generally good enough.
-        my $paddr = sockaddr_in( $port, inet_aton('localhost') );
-        socket( SOCK, PF_INET, SOCK_STREAM, getprotobyname('tcp') )
-            or die "socket: $!";
-        if ( connect( SOCK, $paddr ) ) {
-            close(SOCK);
+
+        if (! IO::Socket::INET->new(
+            Listen    => SOMAXCONN,
+            LocalPort => $port,
+            LocalAddr => '0.0.0.0',
+            Proto     => 'tcp',
+            ReuseAddr => 1,
+        )) {
+            # Port is probably busy.
             redo;
         }
-        close(SOCK);
     }
 
     $ports{$port}++;
@@ -1944,4 +1948,6 @@ END {
     %{'Win32::Locale::Lexicon'};
 }
 
+RT::Base->_ImportOverlays();
+
 1;
